package ifresco.fcpro.client;

import java.text.SimpleDateFormat;
import java.util.Date;
import org.json.JSONException;
import org.json.JSONObject;

/**
 * Models an FCpro Job.
 *
 * @since 1.0
 */
public class FCproJob {

    private String guid;
    private int jobId;
    private int pageCount;
    private FCproStatus status;
    private String owner;
    private String error;
    private String label;
    private Date created;
    private Date converted;
    private final SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");

    /**
     * Getter.
     *
     * @return the job GUID
     */
    public final String getGuid() {
        return guid;
    }

    /**
     * Setter.
     *
     * @param guid the job GUID
     */
    public final void setGuid(String guid) {
        this.guid = guid;
    }

    /**
     * Getter.
     *
     * @return the job ID
     */
    public final int getJobId() {
        return jobId;
    }

    /**
     * Setter.
     *
     * @param jobId the job ID
     */
    public final void setJobId(int jobId) {
        this.jobId = jobId;
    }

    /**
     * Getter.
     *
     * @return the page count
     */
    public final int getPageCount() {
        return pageCount;
    }

    /**
     * Setter.
     *
     * @param pageCount the page count
     */
    public final void setPageCount(int pageCount) {
        this.pageCount = pageCount;
    }

    /**
     * Getter.
     *
     * @return the status
     */
    public final FCproStatus getStatus() {
        return status;
    }

    /**
     * Setter.
     *
     * @param status the status
     */
    public final void setStatus(FCproStatus status) {
        this.status = status;
    }

    /**
     * Setter.
     *
     * @param owner the owner
     */
    public final void setOwner(String owner) {
        this.owner = owner;
    }

    /**
     * Getter.
     *
     * @return the owner
     */
    public final String getOwner() {
        return owner;
    }

    @Override
    public String toString() {
        return "FCproJob{" + "guid=" + guid + ", jobId=" + jobId + ", pageCount=" + pageCount + ", status=" + status + ", owner=" + owner + ", error=" + error + ", label=" + label + ", created=" + created + ", converted=" + converted + '}';
    }

    /**
     * Convert the {@code  FCproJob} to JSO.
     *
     * @return a JSON object
     */
    public JSONObject toJSON() {
        JSONObject json = new JSONObject();

        try {
            json.put("guid", guid);
            json.put("jobId", jobId);
            json.put("pageCount", pageCount);
            json.put("status", status.name());
            json.put("owner", owner);
            json.put("error", error);
            json.put("label", label);
            json.put("created", simpleDateFormat.format(created));
            json.put("converted", simpleDateFormat.format(converted));
        } catch (JSONException e) {
            throw new RuntimeException(e);
        }

        return json;
    }

    /**
     * Getter.
     *
     * @return the error
     */
    public String getError() {
        return error;
    }

    /**
     * Setter.
     *
     * @param error the error
     */
    public void setError(String error) {
        this.error = error;
    }

    /**
     * Setter.
     *
     * @param label the label
     */
    public void setLabel(String label) {
        this.label = label;
    }

    /**
     * Getter.
     *
     * @return the label
     */
    public String getLabel() {
        return label;
    }

    /**
     * Getter.
     *
     * @return the created date
     */
    public Date getCreated() {
        return created;
    }

    /**
     * Setter.
     *
     * @param created the created date
     */
    public void setCreated(Date created) {
        this.created = created;
    }

    /**
     * Getter.
     *
     * @return the converted date
     */
    public Date getConverted() {
        return converted;
    }

    /**
     * Setter.
     *
     * @param converted the converted date
     */
    public void setConverted(Date converted) {
        this.converted = converted;
    }

}
