package ifresco.fcpro.client;

import java.util.ArrayList;
import java.util.List;

/**
 * FCpro Settings value holder object.
 *
 * @since 1.0
 */
public class FCproSetting {

    private String description;
    private String engineName;
    private List<String> additonalOutput = new ArrayList<>();
    private String settingsName;
    private List<String> inputFormats = new ArrayList<>();
    private List<String> inputFormatsMT = new ArrayList<>();
    private List<String> outputFormats = new ArrayList<>();
    private List<String> outputFormatsMT = new ArrayList<>();

    /**
     * Constructor with settings name.
     *
     * @param settingsName the settins name
     */
    public FCproSetting(String settingsName) {
        if (settingsName == null) {
            throw new RuntimeException("SettingsName needs not to be null");
        }
        this.settingsName = settingsName;
    }

    /**
     * Getter.
     *
     * @return the description
     */
    public final String getDescription() {
        return description;
    }

    /**
     * Setter.
     *
     * @param description the description
     */
    public final void setDescription(String description) {
        this.description = description;
    }

    /**
     * Getter.
     *
     * @return the engine name
     */
    public final String getEngineName() {
        return engineName;
    }

    /**
     * Setter.
     *
     * @param engineName the engine name
     */
    public final void setEngineName(String engineName) {
        this.engineName = engineName;
    }

    /**
     * Getter.
     *
     * @return a list of additional output
     */
    public final List<String> getAdditonalOutput() {
        return additonalOutput;
    }

    /**
     * Setter.
     *
     * @param additonalOutput the list of additional output
     */
    public final void setAdditonalOutput(List<String> additonalOutput) {
        this.additonalOutput = additonalOutput;
    }

    /**
     * Getter.
     *
     * @return the settings name
     */
    public final String getSettingsName() {
        return settingsName;
    }

    /**
     * Setter.
     *
     * @param settingsName the settings name
     */
    public final void setSettingsName(String settingsName) {
        this.settingsName = settingsName;
    }

    @Override
    public int hashCode() {
        int hash = settingsName.hashCode();
        if (description != null) {
            hash = hash ^ description.hashCode();
        }
        if (engineName != null) {
            hash = hash ^ engineName.hashCode();
        }
        if (additonalOutput != null) {
            hash = hash ^ additonalOutput.hashCode();
        }

        return hash;
    }

    @Override
    public boolean equals(Object thingy) {
        if (thingy == null) {
            return false;
        }
        if (thingy == this) {
            return true;
        }
        if (!(thingy instanceof FCproSetting)) {
            return false;
        }

        FCproSetting other = (FCproSetting) thingy;

        return isEqual(description, other.description)
                && isEqual(engineName, other.engineName)
                && isEqual(settingsName, other.settingsName)
                && isEqual(additonalOutput, other.additonalOutput);
    }

    private boolean isEqual(Object val1, Object val2) {
        if (val1 == null && val2 == null) {
            return true;
        }
        if (val1 != null) {
            return val1.equals(val2);
        }
        return false;
    }

    /**
     * Getter.
     *
     * @return the list of input formats
     */
    public List<String> getInputFormats() {
        return inputFormats;
    }

    /**
     * Setter.
     *
     * @param inputFormats the list of input formats
     */
    public void setInputFormats(List<String> inputFormats) {
        this.inputFormats = inputFormats;
    }

    /**
     * Getter.
     *
     * @return the list of input format mimetypes
     */
    public List<String> getInputFormatsMT() {
        return inputFormatsMT;
    }

    /**
     * Setter.
     *
     * @param inputFormatsMT the list of input format mimetypes
     */
    public void setInputFormatsMT(List<String> inputFormatsMT) {
        this.inputFormatsMT = inputFormatsMT;
    }

    /**
     * Getter.
     *
     * @return the list of output formats
     */
    public List<String> getOutputFormats() {
        return outputFormats;
    }

    /**
     * Setter.
     *
     * @param outputFormats the list of output formats
     */
    public void setOutputFormats(List<String> outputFormats) {
        this.outputFormats = outputFormats;
    }

    /**
     * Getter.
     *
     * @return the list of output format mimetypes.
     */
    public List<String> getOutputFormatsMT() {
        return outputFormatsMT;
    }

    /**
     * Setter.
     *
     * @param outputFormatsMT the list of output format mimetypes
     */
    public void setOutputFormatsMT(List<String> outputFormatsMT) {
        this.outputFormatsMT = outputFormatsMT;
    }

    @Override
    public String toString() {
        return "FCproSetting{" + "description=" + description + ", engineName=" + engineName + ", additonalOutput=" + additonalOutput + ", settingsName=" + settingsName + ", inputFormats=" + inputFormats + ", inputFormatsMT=" + inputFormatsMT + ", outputFormats=" + outputFormats + ", outputFormatsMT=" + outputFormatsMT + '}';
    }

}
