package ifresco.fcpro.client;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import org.apache.commons.io.IOUtils;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.ResponseHandler;

/**
 * Handler for String responses applicable to be held in memory.
 *
 * @since 1.0
 */
public class StreamResponseHandler implements ResponseHandler<Void> {

    private final OutputStream outputStream;

    /**
     * Constructor with {@code OutputStream}.
     *
     * @param outs the {@code OutputStream}.
     */
    public StreamResponseHandler(OutputStream outs) {
        this.outputStream = outs;
    }

    @Override
    public Void handleResponse(HttpResponse response)
            throws ClientProtocolException, IOException {
        int status = response.getStatusLine().getStatusCode();
        if (status != 200) {
            throw new RuntimeException("HTTP error " + response.getStatusLine());
        }

        HttpEntity entity = response.getEntity();

        if (entity == null) {
            throw new RuntimeException("Expected an HTTP entity.");
        }
        InputStream inputStream = entity.getContent();
        if (inputStream == null) {
            throw new RuntimeException("Expected an InputStream");
        }
        try {
            IOUtils.copyLarge(inputStream, outputStream);
        } finally {
            inputStream.close();
        }
        return null;
    }
}
